# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ExtentSpatial(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bbox': 'list[list[float]]',
        'crs': 'str'
    }

    attribute_map = {
        'bbox': 'bbox',
        'crs': 'crs'
    }

    def __init__(self, bbox=None, crs=None):  # noqa: E501
        """ExtentSpatial - a model defined in Swagger"""  # noqa: E501

        self._bbox = None
        self._crs = None
        self.discriminator = None

        self.bbox = bbox
        if crs is not None:
            self.crs = crs

    @property
    def bbox(self):
        """Gets the bbox of this ExtentSpatial.  # noqa: E501

        One or more bounding boxes that describe the spatial extent of the dataset.  The first bounding box describes the overall spatial extent of the data. All subsequent bounding boxes describe  more precise bounding boxes, e.g., to identify clusters of data. Clients only interested in the overall spatial extent will only need to access the first item in each array.  # noqa: E501

        :return: The bbox of this ExtentSpatial.  # noqa: E501
        :rtype: list[list[float]]
        """
        return self._bbox

    @bbox.setter
    def bbox(self, bbox):
        """Sets the bbox of this ExtentSpatial.

        One or more bounding boxes that describe the spatial extent of the dataset.  The first bounding box describes the overall spatial extent of the data. All subsequent bounding boxes describe  more precise bounding boxes, e.g., to identify clusters of data. Clients only interested in the overall spatial extent will only need to access the first item in each array.  # noqa: E501

        :param bbox: The bbox of this ExtentSpatial.  # noqa: E501
        :type: list[list[float]]
        """
        if bbox is None:
            raise ValueError("Invalid value for `bbox`, must not be `None`")  # noqa: E501

        self._bbox = bbox

    @property
    def crs(self):
        """Gets the crs of this ExtentSpatial.  # noqa: E501

        Coordinate reference system of the coordinates in the spatial extent (property `bbox`). The default reference system is WGS 84 longitude/latitude. In the Core this is the only supported coordinate reference system. Extensions may support additional coordinate reference systems and add additional enum values.  # noqa: E501

        :return: The crs of this ExtentSpatial.  # noqa: E501
        :rtype: str
        """
        return self._crs

    @crs.setter
    def crs(self, crs):
        """Sets the crs of this ExtentSpatial.

        Coordinate reference system of the coordinates in the spatial extent (property `bbox`). The default reference system is WGS 84 longitude/latitude. In the Core this is the only supported coordinate reference system. Extensions may support additional coordinate reference systems and add additional enum values.  # noqa: E501

        :param crs: The crs of this ExtentSpatial.  # noqa: E501
        :type: str
        """
        allowed_values = ["HTTP_WWW_OPENGIS_NET_DEF_CRS_OGC_1_3_CRS84"]  # noqa: E501
        if crs not in allowed_values:
            raise ValueError(
                "Invalid value for `crs` ({0}), must be one of {1}"  # noqa: E501
                .format(crs, allowed_values)
            )

        self._crs = crs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExtentSpatial, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExtentSpatial):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CollectionReferenceParameters(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'index_name': 'str',
        'id_path': 'str',
        'geometry_path': 'str',
        'centroid_path': 'str',
        'h3_path': 'str',
        'timestamp_path': 'str',
        'exclude_fields': 'str',
        'update_max_hits': 'int',
        'taggable_fields': 'str',
        'exclude_wfs_fields': 'str',
        'custom_params': 'dict(str, str)',
        'atom_feed': 'Feed',
        'open_search': 'OpenSearch',
        'inspire': 'Inspire',
        'dublin_core_element_name': 'DublinCoreElementName',
        'raster_tile_url': 'RasterTileURL',
        'raster_tile_width': 'int',
        'raster_tile_height': 'int',
        'filter': 'Filter'
    }

    attribute_map = {
        'index_name': 'index_name',
        'id_path': 'id_path',
        'geometry_path': 'geometry_path',
        'centroid_path': 'centroid_path',
        'h3_path': 'h3_path',
        'timestamp_path': 'timestamp_path',
        'exclude_fields': 'exclude_fields',
        'update_max_hits': 'update_max_hits',
        'taggable_fields': 'taggable_fields',
        'exclude_wfs_fields': 'exclude_wfs_fields',
        'custom_params': 'custom_params',
        'atom_feed': 'atom_feed',
        'open_search': 'open_search',
        'inspire': 'inspire',
        'dublin_core_element_name': 'dublin_core_element_name',
        'raster_tile_url': 'raster_tile_url',
        'raster_tile_width': 'raster_tile_width',
        'raster_tile_height': 'raster_tile_height',
        'filter': 'filter'
    }

    def __init__(self, index_name=None, id_path=None, geometry_path=None, centroid_path=None, h3_path=None, timestamp_path=None, exclude_fields=None, update_max_hits=None, taggable_fields=None, exclude_wfs_fields=None, custom_params=None, atom_feed=None, open_search=None, inspire=None, dublin_core_element_name=None, raster_tile_url=None, raster_tile_width=None, raster_tile_height=None, filter=None):  # noqa: E501
        """CollectionReferenceParameters - a model defined in Swagger"""  # noqa: E501

        self._index_name = None
        self._id_path = None
        self._geometry_path = None
        self._centroid_path = None
        self._h3_path = None
        self._timestamp_path = None
        self._exclude_fields = None
        self._update_max_hits = None
        self._taggable_fields = None
        self._exclude_wfs_fields = None
        self._custom_params = None
        self._atom_feed = None
        self._open_search = None
        self._inspire = None
        self._dublin_core_element_name = None
        self._raster_tile_url = None
        self._raster_tile_width = None
        self._raster_tile_height = None
        self._filter = None
        self.discriminator = None

        self.index_name = index_name
        self.id_path = id_path
        self.geometry_path = geometry_path
        self.centroid_path = centroid_path
        if h3_path is not None:
            self.h3_path = h3_path
        self.timestamp_path = timestamp_path
        if exclude_fields is not None:
            self.exclude_fields = exclude_fields
        if update_max_hits is not None:
            self.update_max_hits = update_max_hits
        if taggable_fields is not None:
            self.taggable_fields = taggable_fields
        if exclude_wfs_fields is not None:
            self.exclude_wfs_fields = exclude_wfs_fields
        if custom_params is not None:
            self.custom_params = custom_params
        if atom_feed is not None:
            self.atom_feed = atom_feed
        if open_search is not None:
            self.open_search = open_search
        if inspire is not None:
            self.inspire = inspire
        if dublin_core_element_name is not None:
            self.dublin_core_element_name = dublin_core_element_name
        if raster_tile_url is not None:
            self.raster_tile_url = raster_tile_url
        if raster_tile_width is not None:
            self.raster_tile_width = raster_tile_width
        if raster_tile_height is not None:
            self.raster_tile_height = raster_tile_height
        if filter is not None:
            self.filter = filter

    @property
    def index_name(self):
        """Gets the index_name of this CollectionReferenceParameters.  # noqa: E501


        :return: The index_name of this CollectionReferenceParameters.  # noqa: E501
        :rtype: str
        """
        return self._index_name

    @index_name.setter
    def index_name(self, index_name):
        """Sets the index_name of this CollectionReferenceParameters.


        :param index_name: The index_name of this CollectionReferenceParameters.  # noqa: E501
        :type: str
        """
        if index_name is None:
            raise ValueError("Invalid value for `index_name`, must not be `None`")  # noqa: E501

        self._index_name = index_name

    @property
    def id_path(self):
        """Gets the id_path of this CollectionReferenceParameters.  # noqa: E501


        :return: The id_path of this CollectionReferenceParameters.  # noqa: E501
        :rtype: str
        """
        return self._id_path

    @id_path.setter
    def id_path(self, id_path):
        """Sets the id_path of this CollectionReferenceParameters.


        :param id_path: The id_path of this CollectionReferenceParameters.  # noqa: E501
        :type: str
        """
        if id_path is None:
            raise ValueError("Invalid value for `id_path`, must not be `None`")  # noqa: E501

        self._id_path = id_path

    @property
    def geometry_path(self):
        """Gets the geometry_path of this CollectionReferenceParameters.  # noqa: E501


        :return: The geometry_path of this CollectionReferenceParameters.  # noqa: E501
        :rtype: str
        """
        return self._geometry_path

    @geometry_path.setter
    def geometry_path(self, geometry_path):
        """Sets the geometry_path of this CollectionReferenceParameters.


        :param geometry_path: The geometry_path of this CollectionReferenceParameters.  # noqa: E501
        :type: str
        """
        if geometry_path is None:
            raise ValueError("Invalid value for `geometry_path`, must not be `None`")  # noqa: E501

        self._geometry_path = geometry_path

    @property
    def centroid_path(self):
        """Gets the centroid_path of this CollectionReferenceParameters.  # noqa: E501


        :return: The centroid_path of this CollectionReferenceParameters.  # noqa: E501
        :rtype: str
        """
        return self._centroid_path

    @centroid_path.setter
    def centroid_path(self, centroid_path):
        """Sets the centroid_path of this CollectionReferenceParameters.


        :param centroid_path: The centroid_path of this CollectionReferenceParameters.  # noqa: E501
        :type: str
        """
        if centroid_path is None:
            raise ValueError("Invalid value for `centroid_path`, must not be `None`")  # noqa: E501

        self._centroid_path = centroid_path

    @property
    def h3_path(self):
        """Gets the h3_path of this CollectionReferenceParameters.  # noqa: E501


        :return: The h3_path of this CollectionReferenceParameters.  # noqa: E501
        :rtype: str
        """
        return self._h3_path

    @h3_path.setter
    def h3_path(self, h3_path):
        """Sets the h3_path of this CollectionReferenceParameters.


        :param h3_path: The h3_path of this CollectionReferenceParameters.  # noqa: E501
        :type: str
        """

        self._h3_path = h3_path

    @property
    def timestamp_path(self):
        """Gets the timestamp_path of this CollectionReferenceParameters.  # noqa: E501


        :return: The timestamp_path of this CollectionReferenceParameters.  # noqa: E501
        :rtype: str
        """
        return self._timestamp_path

    @timestamp_path.setter
    def timestamp_path(self, timestamp_path):
        """Sets the timestamp_path of this CollectionReferenceParameters.


        :param timestamp_path: The timestamp_path of this CollectionReferenceParameters.  # noqa: E501
        :type: str
        """
        if timestamp_path is None:
            raise ValueError("Invalid value for `timestamp_path`, must not be `None`")  # noqa: E501

        self._timestamp_path = timestamp_path

    @property
    def exclude_fields(self):
        """Gets the exclude_fields of this CollectionReferenceParameters.  # noqa: E501


        :return: The exclude_fields of this CollectionReferenceParameters.  # noqa: E501
        :rtype: str
        """
        return self._exclude_fields

    @exclude_fields.setter
    def exclude_fields(self, exclude_fields):
        """Sets the exclude_fields of this CollectionReferenceParameters.


        :param exclude_fields: The exclude_fields of this CollectionReferenceParameters.  # noqa: E501
        :type: str
        """

        self._exclude_fields = exclude_fields

    @property
    def update_max_hits(self):
        """Gets the update_max_hits of this CollectionReferenceParameters.  # noqa: E501


        :return: The update_max_hits of this CollectionReferenceParameters.  # noqa: E501
        :rtype: int
        """
        return self._update_max_hits

    @update_max_hits.setter
    def update_max_hits(self, update_max_hits):
        """Sets the update_max_hits of this CollectionReferenceParameters.


        :param update_max_hits: The update_max_hits of this CollectionReferenceParameters.  # noqa: E501
        :type: int
        """

        self._update_max_hits = update_max_hits

    @property
    def taggable_fields(self):
        """Gets the taggable_fields of this CollectionReferenceParameters.  # noqa: E501


        :return: The taggable_fields of this CollectionReferenceParameters.  # noqa: E501
        :rtype: str
        """
        return self._taggable_fields

    @taggable_fields.setter
    def taggable_fields(self, taggable_fields):
        """Sets the taggable_fields of this CollectionReferenceParameters.


        :param taggable_fields: The taggable_fields of this CollectionReferenceParameters.  # noqa: E501
        :type: str
        """

        self._taggable_fields = taggable_fields

    @property
    def exclude_wfs_fields(self):
        """Gets the exclude_wfs_fields of this CollectionReferenceParameters.  # noqa: E501


        :return: The exclude_wfs_fields of this CollectionReferenceParameters.  # noqa: E501
        :rtype: str
        """
        return self._exclude_wfs_fields

    @exclude_wfs_fields.setter
    def exclude_wfs_fields(self, exclude_wfs_fields):
        """Sets the exclude_wfs_fields of this CollectionReferenceParameters.


        :param exclude_wfs_fields: The exclude_wfs_fields of this CollectionReferenceParameters.  # noqa: E501
        :type: str
        """

        self._exclude_wfs_fields = exclude_wfs_fields

    @property
    def custom_params(self):
        """Gets the custom_params of this CollectionReferenceParameters.  # noqa: E501


        :return: The custom_params of this CollectionReferenceParameters.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._custom_params

    @custom_params.setter
    def custom_params(self, custom_params):
        """Sets the custom_params of this CollectionReferenceParameters.


        :param custom_params: The custom_params of this CollectionReferenceParameters.  # noqa: E501
        :type: dict(str, str)
        """

        self._custom_params = custom_params

    @property
    def atom_feed(self):
        """Gets the atom_feed of this CollectionReferenceParameters.  # noqa: E501


        :return: The atom_feed of this CollectionReferenceParameters.  # noqa: E501
        :rtype: Feed
        """
        return self._atom_feed

    @atom_feed.setter
    def atom_feed(self, atom_feed):
        """Sets the atom_feed of this CollectionReferenceParameters.


        :param atom_feed: The atom_feed of this CollectionReferenceParameters.  # noqa: E501
        :type: Feed
        """

        self._atom_feed = atom_feed

    @property
    def open_search(self):
        """Gets the open_search of this CollectionReferenceParameters.  # noqa: E501


        :return: The open_search of this CollectionReferenceParameters.  # noqa: E501
        :rtype: OpenSearch
        """
        return self._open_search

    @open_search.setter
    def open_search(self, open_search):
        """Sets the open_search of this CollectionReferenceParameters.


        :param open_search: The open_search of this CollectionReferenceParameters.  # noqa: E501
        :type: OpenSearch
        """

        self._open_search = open_search

    @property
    def inspire(self):
        """Gets the inspire of this CollectionReferenceParameters.  # noqa: E501


        :return: The inspire of this CollectionReferenceParameters.  # noqa: E501
        :rtype: Inspire
        """
        return self._inspire

    @inspire.setter
    def inspire(self, inspire):
        """Sets the inspire of this CollectionReferenceParameters.


        :param inspire: The inspire of this CollectionReferenceParameters.  # noqa: E501
        :type: Inspire
        """

        self._inspire = inspire

    @property
    def dublin_core_element_name(self):
        """Gets the dublin_core_element_name of this CollectionReferenceParameters.  # noqa: E501


        :return: The dublin_core_element_name of this CollectionReferenceParameters.  # noqa: E501
        :rtype: DublinCoreElementName
        """
        return self._dublin_core_element_name

    @dublin_core_element_name.setter
    def dublin_core_element_name(self, dublin_core_element_name):
        """Sets the dublin_core_element_name of this CollectionReferenceParameters.


        :param dublin_core_element_name: The dublin_core_element_name of this CollectionReferenceParameters.  # noqa: E501
        :type: DublinCoreElementName
        """

        self._dublin_core_element_name = dublin_core_element_name

    @property
    def raster_tile_url(self):
        """Gets the raster_tile_url of this CollectionReferenceParameters.  # noqa: E501


        :return: The raster_tile_url of this CollectionReferenceParameters.  # noqa: E501
        :rtype: RasterTileURL
        """
        return self._raster_tile_url

    @raster_tile_url.setter
    def raster_tile_url(self, raster_tile_url):
        """Sets the raster_tile_url of this CollectionReferenceParameters.


        :param raster_tile_url: The raster_tile_url of this CollectionReferenceParameters.  # noqa: E501
        :type: RasterTileURL
        """

        self._raster_tile_url = raster_tile_url

    @property
    def raster_tile_width(self):
        """Gets the raster_tile_width of this CollectionReferenceParameters.  # noqa: E501


        :return: The raster_tile_width of this CollectionReferenceParameters.  # noqa: E501
        :rtype: int
        """
        return self._raster_tile_width

    @raster_tile_width.setter
    def raster_tile_width(self, raster_tile_width):
        """Sets the raster_tile_width of this CollectionReferenceParameters.


        :param raster_tile_width: The raster_tile_width of this CollectionReferenceParameters.  # noqa: E501
        :type: int
        """

        self._raster_tile_width = raster_tile_width

    @property
    def raster_tile_height(self):
        """Gets the raster_tile_height of this CollectionReferenceParameters.  # noqa: E501


        :return: The raster_tile_height of this CollectionReferenceParameters.  # noqa: E501
        :rtype: int
        """
        return self._raster_tile_height

    @raster_tile_height.setter
    def raster_tile_height(self, raster_tile_height):
        """Sets the raster_tile_height of this CollectionReferenceParameters.


        :param raster_tile_height: The raster_tile_height of this CollectionReferenceParameters.  # noqa: E501
        :type: int
        """

        self._raster_tile_height = raster_tile_height

    @property
    def filter(self):
        """Gets the filter of this CollectionReferenceParameters.  # noqa: E501


        :return: The filter of this CollectionReferenceParameters.  # noqa: E501
        :rtype: Filter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """Sets the filter of this CollectionReferenceParameters.


        :param filter: The filter of this CollectionReferenceParameters.  # noqa: E501
        :type: Filter
        """

        self._filter = filter

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CollectionReferenceParameters, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CollectionReferenceParameters):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from arlas_api_python.api_client import ApiClient


class StacApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def describe_collection(self, collection_id, **kwargs):  # noqa: E501
        """Describe the feature collection with id `collectionId`  # noqa: E501

        A single Feature Collection for the given id `collectionId`. Request this endpoint to get a full list of metadata for the Feature Collection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_collection(collection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Local identifier of a collection (required)
        :return: Collection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.describe_collection_with_http_info(collection_id, **kwargs)  # noqa: E501
        else:
            (data) = self.describe_collection_with_http_info(collection_id, **kwargs)  # noqa: E501
            return data

    def describe_collection_with_http_info(self, collection_id, **kwargs):  # noqa: E501
        """Describe the feature collection with id `collectionId`  # noqa: E501

        A single Feature Collection for the given id `collectionId`. Request this endpoint to get a full list of metadata for the Feature Collection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_collection_with_http_info(collection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Local identifier of a collection (required)
        :return: Collection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['collection_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method describe_collection" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'collection_id' is set
        if ('collection_id' not in params or
                params['collection_id'] is None):
            raise ValueError("Missing the required parameter `collection_id` when calling `describe_collection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'collection_id' in params:
            path_params['collectionId'] = params['collection_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/stac/collections/{collectionId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Collection',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_api(self, **kwargs):  # noqa: E501
        """OpenAPI  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_api(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_api_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_api_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_api_with_http_info(self, **kwargs):  # noqa: E501
        """OpenAPI  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_api_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_api" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.oai.openapi+json;version=3.0'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/stac/api', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_collections(self, **kwargs):  # noqa: E501
        """The feature collections in the dataset  # noqa: E501

        A body of Feature Collections that belong or are used together with additional links. Request may not return the full set of metadata per Feature Collection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_collections(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CollectionList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_collections_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_collections_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_collections_with_http_info(self, **kwargs):  # noqa: E501
        """The feature collections in the dataset  # noqa: E501

        A body of Feature Collections that belong or are used together with additional links. Request may not return the full set of metadata per Feature Collection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_collections_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CollectionList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_collections" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/stac/collections', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CollectionList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_conformance_declaration(self, **kwargs):  # noqa: E501
        """Conformance  # noqa: E501

        The URIs of all conformance classes supported by the server. To support \"generic\" clients that want to access multiple OGC API Features implementations - and not \"just\" a specific API / server, the server declares the conformance classes it implements and conforms to.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_conformance_declaration(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ConformanceClasses
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_conformance_declaration_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_conformance_declaration_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_conformance_declaration_with_http_info(self, **kwargs):  # noqa: E501
        """Conformance  # noqa: E501

        The URIs of all conformance classes supported by the server. To support \"generic\" clients that want to access multiple OGC API Features implementations - and not \"just\" a specific API / server, the server declares the conformance classes it implements and conforms to.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_conformance_declaration_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ConformanceClasses
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_conformance_declaration" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/stac/conformance', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConformanceClasses',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_feature(self, collection_id, feature_id, **kwargs):  # noqa: E501
        """Fetch a single feature  # noqa: E501

        Fetch the feature with id `featureId` in the feature collection with id `collectionId`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_feature(collection_id, feature_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Local identifier of a collection (required)
        :param str feature_id: Local identifier of a feature (required)
        :return: Item
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_feature_with_http_info(collection_id, feature_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_feature_with_http_info(collection_id, feature_id, **kwargs)  # noqa: E501
            return data

    def get_feature_with_http_info(self, collection_id, feature_id, **kwargs):  # noqa: E501
        """Fetch a single feature  # noqa: E501

        Fetch the feature with id `featureId` in the feature collection with id `collectionId`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_feature_with_http_info(collection_id, feature_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Local identifier of a collection (required)
        :param str feature_id: Local identifier of a feature (required)
        :return: Item
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['collection_id', 'feature_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_feature" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'collection_id' is set
        if ('collection_id' not in params or
                params['collection_id'] is None):
            raise ValueError("Missing the required parameter `collection_id` when calling `get_feature`")  # noqa: E501
        # verify the required parameter 'feature_id' is set
        if ('feature_id' not in params or
                params['feature_id'] is None):
            raise ValueError("Missing the required parameter `feature_id` when calling `get_feature`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'collection_id' in params:
            path_params['collectionId'] = params['collection_id']  # noqa: E501
        if 'feature_id' in params:
            path_params['featureId'] = params['feature_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/geo+json', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/stac/collections/{collectionId}/items/{featureId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Item',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_features(self, collection_id, **kwargs):  # noqa: E501
        """Fetch features  # noqa: E501

        Fetch features of the feature collection with id `collectionId`. Every feature in a dataset belongs to a collection. A dataset may consist of multiple feature collections. A feature collection is often a collection of features of a similar type, based on a common schema.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_features(collection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Local identifier of a collection (required)
        :param str limit: The optional limit parameter limits the number of items that are presented in the response document. Only items are counted that are on the first level of the collection in the response document. Nested objects contained within the explicitly requested items shall not be counted. Minimum &#x3D; 1. Maximum &#x3D; 10000. Default &#x3D; 10.
        :param str bbox: Only features that have a geometry that intersects the bounding box are selected. The bounding box is provided as four or six numbers, depending on whether the coordinate reference system includes a vertical axis (height or depth):   * Lower left corner, coordinate axis 1   * Lower left corner, coordinate axis 2   * Minimum value, coordinate axis 3 (optional)   * Upper right corner, coordinate axis 1   * Upper right corner, coordinate axis 2   * Maximum value, coordinate axis 3 (optional)  The coordinate reference system of the values is WGS 84 longitude/latitude (http://www.opengis.net/def/crs/OGC/1.3/CRS84). For WGS 84 longitude/latitude the values are in most cases the sequence of minimum longitude, minimum latitude, maximum longitude and maximum latitude. However, in cases where the box spans the antimeridian the first value (west-most box edge) is larger than the third value (east-most box edge). If the vertical axis is included, the third and the sixth number are the bottom and the top of the 3-dimensional bounding box. If a feature has multiple spatial geometry properties, it is the decision of the server whether only a single spatial geometry property is used to determine the extent or all relevant geometries.
        :param str _datetime: Either a date-time or an interval, open or closed. Date and time expressions adhere to RFC 3339. Open intervals are expressed using double-dots.  Examples:   * A date-time: \"2018-02-12T23:20:50Z\"   * A closed interval: \"2018-02-12T00:00:00Z/2018-03-18T12:31:12Z\"   * Open intervals: \"2018-02-12T00:00:00Z/..\" or \"../2018-03-18T12:31:12Z\"  Only features that have a temporal property that intersects the value of &#x60;datetime&#x60; are selected. If a feature has multiple temporal properties, it is the decision of the server whether only a single temporal property is used to determine the extent or all relevant temporal properties.
        :param str sortby: **Optional Extension:** Sort  An array of property names, prefixed by either \"+\" for ascending or \"-\" for descending. If no prefix is provided, \"+\" is assumed.
        :param int _from: From index to start the search from. Defaults to 0.
        :param str after: List of values of fields present in sort param that are used to search after.    > **What it does**: Retrieve the data placed after the pointed element, given the provided order (sort).   > __**Restriction 1**__: **after** param works only combined with **sort** param.   > __**Syntax**__: `after={value1},{value2},...,{valueN} & sort={field1},{field2},...,{fieldN}`.   > **Note 1**: *{value1}` and `{value2}` are the values of `{field1}` and `{field2}` in the last hit returned in the previous search   > **Note 2**: The order of fields and values matters. *{value1},{value2}* must be in the same order of *{field1},{field2}* in **sort** param   > **Note 3**:  The last field `{fieldN}` must be the id field specified in the collection **collection.params.idPath** (returned as **md.id**) and `{valueN}` its corresponding value.   > __**Example**__: *sort=`-date,id` & **after**=`01/02/2019,abcd1234`*. Gets the following hits of the previous search that stopped at date *01/02/2019* and id *abcd1234*.   > __**Restriction 2**__: **from** param must be set to 0 or kept unset   
        :param str before: Same idea that after param, but to retrieve the data placed before the pointed element, given the provided order (sort).
        :return: StacFeatureCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_features_with_http_info(collection_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_features_with_http_info(collection_id, **kwargs)  # noqa: E501
            return data

    def get_features_with_http_info(self, collection_id, **kwargs):  # noqa: E501
        """Fetch features  # noqa: E501

        Fetch features of the feature collection with id `collectionId`. Every feature in a dataset belongs to a collection. A dataset may consist of multiple feature collections. A feature collection is often a collection of features of a similar type, based on a common schema.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_features_with_http_info(collection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Local identifier of a collection (required)
        :param str limit: The optional limit parameter limits the number of items that are presented in the response document. Only items are counted that are on the first level of the collection in the response document. Nested objects contained within the explicitly requested items shall not be counted. Minimum &#x3D; 1. Maximum &#x3D; 10000. Default &#x3D; 10.
        :param str bbox: Only features that have a geometry that intersects the bounding box are selected. The bounding box is provided as four or six numbers, depending on whether the coordinate reference system includes a vertical axis (height or depth):   * Lower left corner, coordinate axis 1   * Lower left corner, coordinate axis 2   * Minimum value, coordinate axis 3 (optional)   * Upper right corner, coordinate axis 1   * Upper right corner, coordinate axis 2   * Maximum value, coordinate axis 3 (optional)  The coordinate reference system of the values is WGS 84 longitude/latitude (http://www.opengis.net/def/crs/OGC/1.3/CRS84). For WGS 84 longitude/latitude the values are in most cases the sequence of minimum longitude, minimum latitude, maximum longitude and maximum latitude. However, in cases where the box spans the antimeridian the first value (west-most box edge) is larger than the third value (east-most box edge). If the vertical axis is included, the third and the sixth number are the bottom and the top of the 3-dimensional bounding box. If a feature has multiple spatial geometry properties, it is the decision of the server whether only a single spatial geometry property is used to determine the extent or all relevant geometries.
        :param str _datetime: Either a date-time or an interval, open or closed. Date and time expressions adhere to RFC 3339. Open intervals are expressed using double-dots.  Examples:   * A date-time: \"2018-02-12T23:20:50Z\"   * A closed interval: \"2018-02-12T00:00:00Z/2018-03-18T12:31:12Z\"   * Open intervals: \"2018-02-12T00:00:00Z/..\" or \"../2018-03-18T12:31:12Z\"  Only features that have a temporal property that intersects the value of &#x60;datetime&#x60; are selected. If a feature has multiple temporal properties, it is the decision of the server whether only a single temporal property is used to determine the extent or all relevant temporal properties.
        :param str sortby: **Optional Extension:** Sort  An array of property names, prefixed by either \"+\" for ascending or \"-\" for descending. If no prefix is provided, \"+\" is assumed.
        :param int _from: From index to start the search from. Defaults to 0.
        :param str after: List of values of fields present in sort param that are used to search after.    > **What it does**: Retrieve the data placed after the pointed element, given the provided order (sort).   > __**Restriction 1**__: **after** param works only combined with **sort** param.   > __**Syntax**__: `after={value1},{value2},...,{valueN} & sort={field1},{field2},...,{fieldN}`.   > **Note 1**: *{value1}` and `{value2}` are the values of `{field1}` and `{field2}` in the last hit returned in the previous search   > **Note 2**: The order of fields and values matters. *{value1},{value2}* must be in the same order of *{field1},{field2}* in **sort** param   > **Note 3**:  The last field `{fieldN}` must be the id field specified in the collection **collection.params.idPath** (returned as **md.id**) and `{valueN}` its corresponding value.   > __**Example**__: *sort=`-date,id` & **after**=`01/02/2019,abcd1234`*. Gets the following hits of the previous search that stopped at date *01/02/2019* and id *abcd1234*.   > __**Restriction 2**__: **from** param must be set to 0 or kept unset   
        :param str before: Same idea that after param, but to retrieve the data placed before the pointed element, given the provided order (sort).
        :return: StacFeatureCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['collection_id', 'limit', 'bbox', '_datetime', 'sortby', '_from', 'after', 'before']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_features" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'collection_id' is set
        if ('collection_id' not in params or
                params['collection_id'] is None):
            raise ValueError("Missing the required parameter `collection_id` when calling `get_features`")  # noqa: E501

        if 'limit' in params and params['limit'] > 10000:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_features`, must be a value less than or equal to `10000`")  # noqa: E501
        if 'limit' in params and params['limit'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_features`, must be a value greater than or equal to `1`")  # noqa: E501
        if '_from' in params and params['_from'] < 0:  # noqa: E501
            raise ValueError("Invalid value for parameter `_from` when calling `get_features`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'collection_id' in params:
            path_params['collectionId'] = params['collection_id']  # noqa: E501

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'bbox' in params:
            query_params.append(('bbox', params['bbox']))  # noqa: E501
        if '_datetime' in params:
            query_params.append(('datetime', params['_datetime']))  # noqa: E501
        if 'sortby' in params:
            query_params.append(('sortby', params['sortby']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'after' in params:
            query_params.append(('after', params['after']))  # noqa: E501
        if 'before' in params:
            query_params.append(('before', params['before']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/geo+json', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/stac/collections/{collectionId}/items', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StacFeatureCollection',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_item_search(self, **kwargs):  # noqa: E501
        """Search STAC items with simple filtering.  # noqa: E501

        Retrieve Items matching filters. Intended as a shorthand API for simple queries.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_item_search(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bbox: Only features that have a geometry that intersects the bounding box are selected. The bounding box is provided as four or six numbers, depending on whether the coordinate reference system includes a vertical axis (height or depth):   * Lower left corner, coordinate axis 1   * Lower left corner, coordinate axis 2   * Minimum value, coordinate axis 3 (optional)   * Upper right corner, coordinate axis 1   * Upper right corner, coordinate axis 2   * Maximum value, coordinate axis 3 (optional)  The coordinate reference system of the values is WGS 84 longitude/latitude (http://www.opengis.net/def/crs/OGC/1.3/CRS84). For WGS 84 longitude/latitude the values are in most cases the sequence of minimum longitude, minimum latitude, maximum longitude and maximum latitude. However, in cases where the box spans the antimeridian the first value (west-most box edge) is larger than the third value (east-most box edge). If the vertical axis is included, the third and the sixth number are the bottom and the top of the 3-dimensional bounding box. If a feature has multiple spatial geometry properties, it is the decision of the server whether only a single spatial geometry property is used to determine the extent or all relevant geometries.  Example: The bounding box of the New Zealand Exclusive Economic Zone in WGS 84 (from 160.6°E to 170°W and from 55.95°S to 25.89°S) would be represented in JSON as &#x60;[160.6, -55.95, -170, -25.89]&#x60; and in a query as &#x60;bbox&#x3D;160.6,-55.95,-170,-25.89&#x60;.
        :param str intersects: The optional intersects parameter filters the result Items in the same way as bbox, only with a GeoJSON Geometry rather than a bbox.
        :param str _datetime: Either a date-time or an interval, open or closed. Date and time expressions adhere to RFC 3339. Open intervals are expressed using double-dots.  Examples:   * A date-time: \"2018-02-12T23:20:50Z\"   * A closed interval: \"2018-02-12T00:00:00Z/2018-03-18T12:31:12Z\"   * Open intervals: \"2018-02-12T00:00:00Z/..\" or \"../2018-03-18T12:31:12Z\"  Only features that have a temporal property that intersects the value of &#x60;datetime&#x60; are selected. If a feature has multiple temporal properties, it is the decision of the server whether only a single temporal property is used to determine the extent or all relevant temporal properties.
        :param str limit: The optional limit parameter limits the number of items that are presented in the response document. Only items are counted that are on the first level of the collection in the response document. Nested objects contained within the explicitly requested items shall not be counted.  Minimum &#x3D; 1. Maximum &#x3D; 10000. Default &#x3D; 10.
        :param list[str] ids: Array of Item ids to return.
        :param list[str] collections: Array of Collection IDs to include in the search for items. Only Item objects in one of the provided collections will be searched 
        :param str sortby: **Optional Extension:** Sort  An array of property names, prefixed by either \"+\" for ascending or \"-\" for descending. If no prefix is provided, \"+\" is assumed.
        :param int _from: From index to start the search from. Defaults to 0.
        :param str after: List of values of fields present in sort param that are used to search after.    > **What it does**: Retrieve the data placed after the pointed element, given the provided order (sort).   > __**Restriction 1**__: **after** param works only combined with **sort** param.   > __**Syntax**__: `after={value1},{value2},...,{valueN} & sort={field1},{field2},...,{fieldN}`.   > **Note 1**: *{value1}` and `{value2}` are the values of `{field1}` and `{field2}` in the last hit returned in the previous search   > **Note 2**: The order of fields and values matters. *{value1},{value2}* must be in the same order of *{field1},{field2}* in **sort** param   > **Note 3**:  The last field `{fieldN}` must be the id field specified in the collection **collection.params.idPath** (returned as **md.id**) and `{valueN}` its corresponding value.   > __**Example**__: *sort=`-date,id` & **after**=`01/02/2019,abcd1234`*. Gets the following hits of the previous search that stopped at date *01/02/2019* and id *abcd1234*.   > __**Restriction 2**__: **from** param must be set to 0 or kept unset   
        :param str before: Same idea that after param, but to retrieve the data placed before the pointed element, given the provided order (sort).
        :return: StacFeatureCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_item_search_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_item_search_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_item_search_with_http_info(self, **kwargs):  # noqa: E501
        """Search STAC items with simple filtering.  # noqa: E501

        Retrieve Items matching filters. Intended as a shorthand API for simple queries.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_item_search_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bbox: Only features that have a geometry that intersects the bounding box are selected. The bounding box is provided as four or six numbers, depending on whether the coordinate reference system includes a vertical axis (height or depth):   * Lower left corner, coordinate axis 1   * Lower left corner, coordinate axis 2   * Minimum value, coordinate axis 3 (optional)   * Upper right corner, coordinate axis 1   * Upper right corner, coordinate axis 2   * Maximum value, coordinate axis 3 (optional)  The coordinate reference system of the values is WGS 84 longitude/latitude (http://www.opengis.net/def/crs/OGC/1.3/CRS84). For WGS 84 longitude/latitude the values are in most cases the sequence of minimum longitude, minimum latitude, maximum longitude and maximum latitude. However, in cases where the box spans the antimeridian the first value (west-most box edge) is larger than the third value (east-most box edge). If the vertical axis is included, the third and the sixth number are the bottom and the top of the 3-dimensional bounding box. If a feature has multiple spatial geometry properties, it is the decision of the server whether only a single spatial geometry property is used to determine the extent or all relevant geometries.  Example: The bounding box of the New Zealand Exclusive Economic Zone in WGS 84 (from 160.6°E to 170°W and from 55.95°S to 25.89°S) would be represented in JSON as &#x60;[160.6, -55.95, -170, -25.89]&#x60; and in a query as &#x60;bbox&#x3D;160.6,-55.95,-170,-25.89&#x60;.
        :param str intersects: The optional intersects parameter filters the result Items in the same way as bbox, only with a GeoJSON Geometry rather than a bbox.
        :param str _datetime: Either a date-time or an interval, open or closed. Date and time expressions adhere to RFC 3339. Open intervals are expressed using double-dots.  Examples:   * A date-time: \"2018-02-12T23:20:50Z\"   * A closed interval: \"2018-02-12T00:00:00Z/2018-03-18T12:31:12Z\"   * Open intervals: \"2018-02-12T00:00:00Z/..\" or \"../2018-03-18T12:31:12Z\"  Only features that have a temporal property that intersects the value of &#x60;datetime&#x60; are selected. If a feature has multiple temporal properties, it is the decision of the server whether only a single temporal property is used to determine the extent or all relevant temporal properties.
        :param str limit: The optional limit parameter limits the number of items that are presented in the response document. Only items are counted that are on the first level of the collection in the response document. Nested objects contained within the explicitly requested items shall not be counted.  Minimum &#x3D; 1. Maximum &#x3D; 10000. Default &#x3D; 10.
        :param list[str] ids: Array of Item ids to return.
        :param list[str] collections: Array of Collection IDs to include in the search for items. Only Item objects in one of the provided collections will be searched 
        :param str sortby: **Optional Extension:** Sort  An array of property names, prefixed by either \"+\" for ascending or \"-\" for descending. If no prefix is provided, \"+\" is assumed.
        :param int _from: From index to start the search from. Defaults to 0.
        :param str after: List of values of fields present in sort param that are used to search after.    > **What it does**: Retrieve the data placed after the pointed element, given the provided order (sort).   > __**Restriction 1**__: **after** param works only combined with **sort** param.   > __**Syntax**__: `after={value1},{value2},...,{valueN} & sort={field1},{field2},...,{fieldN}`.   > **Note 1**: *{value1}` and `{value2}` are the values of `{field1}` and `{field2}` in the last hit returned in the previous search   > **Note 2**: The order of fields and values matters. *{value1},{value2}* must be in the same order of *{field1},{field2}* in **sort** param   > **Note 3**:  The last field `{fieldN}` must be the id field specified in the collection **collection.params.idPath** (returned as **md.id**) and `{valueN}` its corresponding value.   > __**Example**__: *sort=`-date,id` & **after**=`01/02/2019,abcd1234`*. Gets the following hits of the previous search that stopped at date *01/02/2019* and id *abcd1234*.   > __**Restriction 2**__: **from** param must be set to 0 or kept unset   
        :param str before: Same idea that after param, but to retrieve the data placed before the pointed element, given the provided order (sort).
        :return: StacFeatureCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bbox', 'intersects', '_datetime', 'limit', 'ids', 'collections', 'sortby', '_from', 'after', 'before']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_item_search" % key
                )
            params[key] = val
        del params['kwargs']

        if 'limit' in params and params['limit'] > 10000:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_item_search`, must be a value less than or equal to `10000`")  # noqa: E501
        if 'limit' in params and params['limit'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_item_search`, must be a value greater than or equal to `1`")  # noqa: E501
        if '_from' in params and params['_from'] < 0:  # noqa: E501
            raise ValueError("Invalid value for parameter `_from` when calling `get_item_search`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'bbox' in params:
            query_params.append(('bbox', params['bbox']))  # noqa: E501
        if 'intersects' in params:
            query_params.append(('intersects', params['intersects']))  # noqa: E501
        if '_datetime' in params:
            query_params.append(('datetime', params['_datetime']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'ids' in params:
            query_params.append(('ids', params['ids']))  # noqa: E501
            collection_formats['ids'] = 'multi'  # noqa: E501
        if 'collections' in params:
            query_params.append(('collections', params['collections']))  # noqa: E501
            collection_formats['collections'] = 'multi'  # noqa: E501
        if 'sortby' in params:
            query_params.append(('sortby', params['sortby']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'after' in params:
            query_params.append(('after', params['after']))  # noqa: E501
        if 'before' in params:
            query_params.append(('before', params['before']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/geo+json', 'text/html', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/stac/search', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StacFeatureCollection',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_landing_page(self, **kwargs):  # noqa: E501
        """Landing page  # noqa: E501

        Returns the root STAC Catalog or STAC Collection that is the entry point for users to browse with STAC Browser or for search engines to crawl. This can either return a single STAC Collection or more commonly a STAC catalog. The landing page provides links to the API definition (link relations `service-desc` and `service-doc`) and the STAC records such as collections/catalogs (link relation `child`) or items (link relation `item`). Extensions may add additional links with new relation types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_landing_page(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: LandingPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_landing_page_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_landing_page_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_landing_page_with_http_info(self, **kwargs):  # noqa: E501
        """Landing page  # noqa: E501

        Returns the root STAC Catalog or STAC Collection that is the entry point for users to browse with STAC Browser or for search engines to crawl. This can either return a single STAC Collection or more commonly a STAC catalog. The landing page provides links to the API definition (link relations `service-desc` and `service-doc`) and the STAC records such as collections/catalogs (link relation `child`) or items (link relation `item`). Extensions may add additional links with new relation types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_landing_page_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: LandingPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_landing_page" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/stac', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LandingPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_item_search(self, **kwargs):  # noqa: E501
        """Search STAC items with full-featured filtering.  # noqa: E501

        Retrieve items matching filters. Intended as the standard, full-featured query API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_item_search(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchBody body:
        :return: StacFeatureCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_item_search_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.post_item_search_with_http_info(**kwargs)  # noqa: E501
            return data

    def post_item_search_with_http_info(self, **kwargs):  # noqa: E501
        """Search STAC items with full-featured filtering.  # noqa: E501

        Retrieve items matching filters. Intended as the standard, full-featured query API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_item_search_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchBody body:
        :return: StacFeatureCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_item_search" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/geo+json', 'text/html', 'application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/stac/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StacFeatureCollection',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import arlas_api_python
from arlas_api_python.api.stac_api import StacApi  # noqa: E501
from arlas_api_python.rest import ApiException


class TestStacApi(unittest.TestCase):
    """StacApi unit test stubs"""

    def setUp(self):
        self.api = arlas_api_python.api.stac_api.StacApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_describe_collection(self):
        """Test case for describe_collection

        Describe the feature collection with id `collectionId`  # noqa: E501
        """
        pass

    def test_get_api(self):
        """Test case for get_api

        OpenAPI  # noqa: E501
        """
        pass

    def test_get_collections(self):
        """Test case for get_collections

        The feature collections in the dataset  # noqa: E501
        """
        pass

    def test_get_conformance_declaration(self):
        """Test case for get_conformance_declaration

        Conformance  # noqa: E501
        """
        pass

    def test_get_feature(self):
        """Test case for get_feature

        Fetch a single feature  # noqa: E501
        """
        pass

    def test_get_features(self):
        """Test case for get_features

        Fetch features  # noqa: E501
        """
        pass

    def test_get_item_search(self):
        """Test case for get_item_search

        Search STAC items with simple filtering.  # noqa: E501
        """
        pass

    def test_get_landing_page(self):
        """Test case for get_landing_page

        Landing page  # noqa: E501
        """
        pass

    def test_post_item_search(self):
        """Test case for post_item_search

        Search STAC items with full-featured filtering.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Aggregation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'field': 'str',
        'interval': 'Interval',
        'format': 'str',
        'metrics': 'list[Metric]',
        'order': 'str',
        'on': 'str',
        'size': 'str',
        'include': 'str',
        'raw_geometries': 'list[RawGeometry]',
        'aggregated_geometries': 'list[str]',
        'fetch_hits': 'HitsFetcher'
    }

    attribute_map = {
        'type': 'type',
        'field': 'field',
        'interval': 'interval',
        'format': 'format',
        'metrics': 'metrics',
        'order': 'order',
        'on': 'on',
        'size': 'size',
        'include': 'include',
        'raw_geometries': 'raw_geometries',
        'aggregated_geometries': 'aggregated_geometries',
        'fetch_hits': 'fetch_hits'
    }

    def __init__(self, type=None, field=None, interval=None, format=None, metrics=None, order=None, on=None, size=None, include=None, raw_geometries=None, aggregated_geometries=None, fetch_hits=None):  # noqa: E501
        """Aggregation - a model defined in Swagger"""  # noqa: E501

        self._type = None
        self._field = None
        self._interval = None
        self._format = None
        self._metrics = None
        self._order = None
        self._on = None
        self._size = None
        self._include = None
        self._raw_geometries = None
        self._aggregated_geometries = None
        self._fetch_hits = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if field is not None:
            self.field = field
        if interval is not None:
            self.interval = interval
        if format is not None:
            self.format = format
        if metrics is not None:
            self.metrics = metrics
        if order is not None:
            self.order = order
        if on is not None:
            self.on = on
        if size is not None:
            self.size = size
        if include is not None:
            self.include = include
        if raw_geometries is not None:
            self.raw_geometries = raw_geometries
        if aggregated_geometries is not None:
            self.aggregated_geometries = aggregated_geometries
        if fetch_hits is not None:
            self.fetch_hits = fetch_hits

    @property
    def type(self):
        """Gets the type of this Aggregation.  # noqa: E501


        :return: The type of this Aggregation.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Aggregation.


        :param type: The type of this Aggregation.  # noqa: E501
        :type: str
        """
        allowed_values = ["datehistogram", "geohash", "geotile", "histogram", "term", "h3"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def field(self):
        """Gets the field of this Aggregation.  # noqa: E501


        :return: The field of this Aggregation.  # noqa: E501
        :rtype: str
        """
        return self._field

    @field.setter
    def field(self, field):
        """Sets the field of this Aggregation.


        :param field: The field of this Aggregation.  # noqa: E501
        :type: str
        """

        self._field = field

    @property
    def interval(self):
        """Gets the interval of this Aggregation.  # noqa: E501


        :return: The interval of this Aggregation.  # noqa: E501
        :rtype: Interval
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this Aggregation.


        :param interval: The interval of this Aggregation.  # noqa: E501
        :type: Interval
        """

        self._interval = interval

    @property
    def format(self):
        """Gets the format of this Aggregation.  # noqa: E501


        :return: The format of this Aggregation.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this Aggregation.


        :param format: The format of this Aggregation.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def metrics(self):
        """Gets the metrics of this Aggregation.  # noqa: E501


        :return: The metrics of this Aggregation.  # noqa: E501
        :rtype: list[Metric]
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """Sets the metrics of this Aggregation.


        :param metrics: The metrics of this Aggregation.  # noqa: E501
        :type: list[Metric]
        """

        self._metrics = metrics

    @property
    def order(self):
        """Gets the order of this Aggregation.  # noqa: E501


        :return: The order of this Aggregation.  # noqa: E501
        :rtype: str
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this Aggregation.


        :param order: The order of this Aggregation.  # noqa: E501
        :type: str
        """
        allowed_values = ["asc", "desc"]  # noqa: E501
        if order not in allowed_values:
            raise ValueError(
                "Invalid value for `order` ({0}), must be one of {1}"  # noqa: E501
                .format(order, allowed_values)
            )

        self._order = order

    @property
    def on(self):
        """Gets the on of this Aggregation.  # noqa: E501


        :return: The on of this Aggregation.  # noqa: E501
        :rtype: str
        """
        return self._on

    @on.setter
    def on(self, on):
        """Sets the on of this Aggregation.


        :param on: The on of this Aggregation.  # noqa: E501
        :type: str
        """
        allowed_values = ["field", "count", "result"]  # noqa: E501
        if on not in allowed_values:
            raise ValueError(
                "Invalid value for `on` ({0}), must be one of {1}"  # noqa: E501
                .format(on, allowed_values)
            )

        self._on = on

    @property
    def size(self):
        """Gets the size of this Aggregation.  # noqa: E501


        :return: The size of this Aggregation.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Aggregation.


        :param size: The size of this Aggregation.  # noqa: E501
        :type: str
        """

        self._size = size

    @property
    def include(self):
        """Gets the include of this Aggregation.  # noqa: E501


        :return: The include of this Aggregation.  # noqa: E501
        :rtype: str
        """
        return self._include

    @include.setter
    def include(self, include):
        """Sets the include of this Aggregation.


        :param include: The include of this Aggregation.  # noqa: E501
        :type: str
        """

        self._include = include

    @property
    def raw_geometries(self):
        """Gets the raw_geometries of this Aggregation.  # noqa: E501


        :return: The raw_geometries of this Aggregation.  # noqa: E501
        :rtype: list[RawGeometry]
        """
        return self._raw_geometries

    @raw_geometries.setter
    def raw_geometries(self, raw_geometries):
        """Sets the raw_geometries of this Aggregation.


        :param raw_geometries: The raw_geometries of this Aggregation.  # noqa: E501
        :type: list[RawGeometry]
        """

        self._raw_geometries = raw_geometries

    @property
    def aggregated_geometries(self):
        """Gets the aggregated_geometries of this Aggregation.  # noqa: E501


        :return: The aggregated_geometries of this Aggregation.  # noqa: E501
        :rtype: list[str]
        """
        return self._aggregated_geometries

    @aggregated_geometries.setter
    def aggregated_geometries(self, aggregated_geometries):
        """Sets the aggregated_geometries of this Aggregation.


        :param aggregated_geometries: The aggregated_geometries of this Aggregation.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["BBOX", "CENTROID", "CELL", "CELLCENTER", "GEOHASH", "GEOHASH_CENTER"]  # noqa: E501
        if not set(aggregated_geometries).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `aggregated_geometries` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(aggregated_geometries) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._aggregated_geometries = aggregated_geometries

    @property
    def fetch_hits(self):
        """Gets the fetch_hits of this Aggregation.  # noqa: E501


        :return: The fetch_hits of this Aggregation.  # noqa: E501
        :rtype: HitsFetcher
        """
        return self._fetch_hits

    @fetch_hits.setter
    def fetch_hits(self, fetch_hits):
        """Sets the fetch_hits of this Aggregation.


        :param fetch_hits: The fetch_hits of this Aggregation.  # noqa: E501
        :type: HitsFetcher
        """

        self._fetch_hits = fetch_hits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Aggregation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Aggregation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class InspireLimitationAccess(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'access_constraints': 'str',
        'other_constraints': 'str',
        'classification': 'str'
    }

    attribute_map = {
        'access_constraints': 'access_constraints',
        'other_constraints': 'other_constraints',
        'classification': 'classification'
    }

    def __init__(self, access_constraints=None, other_constraints=None, classification=None):  # noqa: E501
        """InspireLimitationAccess - a model defined in Swagger"""  # noqa: E501

        self._access_constraints = None
        self._other_constraints = None
        self._classification = None
        self.discriminator = None

        if access_constraints is not None:
            self.access_constraints = access_constraints
        if other_constraints is not None:
            self.other_constraints = other_constraints
        if classification is not None:
            self.classification = classification

    @property
    def access_constraints(self):
        """Gets the access_constraints of this InspireLimitationAccess.  # noqa: E501


        :return: The access_constraints of this InspireLimitationAccess.  # noqa: E501
        :rtype: str
        """
        return self._access_constraints

    @access_constraints.setter
    def access_constraints(self, access_constraints):
        """Sets the access_constraints of this InspireLimitationAccess.


        :param access_constraints: The access_constraints of this InspireLimitationAccess.  # noqa: E501
        :type: str
        """

        self._access_constraints = access_constraints

    @property
    def other_constraints(self):
        """Gets the other_constraints of this InspireLimitationAccess.  # noqa: E501


        :return: The other_constraints of this InspireLimitationAccess.  # noqa: E501
        :rtype: str
        """
        return self._other_constraints

    @other_constraints.setter
    def other_constraints(self, other_constraints):
        """Sets the other_constraints of this InspireLimitationAccess.


        :param other_constraints: The other_constraints of this InspireLimitationAccess.  # noqa: E501
        :type: str
        """

        self._other_constraints = other_constraints

    @property
    def classification(self):
        """Gets the classification of this InspireLimitationAccess.  # noqa: E501


        :return: The classification of this InspireLimitationAccess.  # noqa: E501
        :rtype: str
        """
        return self._classification

    @classification.setter
    def classification(self, classification):
        """Sets the classification of this InspireLimitationAccess.


        :param classification: The classification of this InspireLimitationAccess.  # noqa: E501
        :type: str
        """

        self._classification = classification

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InspireLimitationAccess, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InspireLimitationAccess):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ComputationRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'filter': 'Filter',
        'form': 'Form',
        'field': 'str',
        'metric': 'str'
    }

    attribute_map = {
        'filter': 'filter',
        'form': 'form',
        'field': 'field',
        'metric': 'metric'
    }

    def __init__(self, filter=None, form=None, field=None, metric=None):  # noqa: E501
        """ComputationRequest - a model defined in Swagger"""  # noqa: E501

        self._filter = None
        self._form = None
        self._field = None
        self._metric = None
        self.discriminator = None

        if filter is not None:
            self.filter = filter
        if form is not None:
            self.form = form
        if field is not None:
            self.field = field
        if metric is not None:
            self.metric = metric

    @property
    def filter(self):
        """Gets the filter of this ComputationRequest.  # noqa: E501


        :return: The filter of this ComputationRequest.  # noqa: E501
        :rtype: Filter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """Sets the filter of this ComputationRequest.


        :param filter: The filter of this ComputationRequest.  # noqa: E501
        :type: Filter
        """

        self._filter = filter

    @property
    def form(self):
        """Gets the form of this ComputationRequest.  # noqa: E501


        :return: The form of this ComputationRequest.  # noqa: E501
        :rtype: Form
        """
        return self._form

    @form.setter
    def form(self, form):
        """Sets the form of this ComputationRequest.


        :param form: The form of this ComputationRequest.  # noqa: E501
        :type: Form
        """

        self._form = form

    @property
    def field(self):
        """Gets the field of this ComputationRequest.  # noqa: E501


        :return: The field of this ComputationRequest.  # noqa: E501
        :rtype: str
        """
        return self._field

    @field.setter
    def field(self, field):
        """Sets the field of this ComputationRequest.


        :param field: The field of this ComputationRequest.  # noqa: E501
        :type: str
        """

        self._field = field

    @property
    def metric(self):
        """Gets the metric of this ComputationRequest.  # noqa: E501


        :return: The metric of this ComputationRequest.  # noqa: E501
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """Sets the metric of this ComputationRequest.


        :param metric: The metric of this ComputationRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["AVG", "MAX", "MIN", "SUM", "CARDINALITY", "SPANNING", "GEOBBOX", "GEOCENTROID"]  # noqa: E501
        if metric not in allowed_values:
            raise ValueError(
                "Invalid value for `metric` ({0}), must be one of {1}"  # noqa: E501
                .format(metric, allowed_values)
            )

        self._metric = metric

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ComputationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ComputationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ExtentTemporal(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'interval': 'list[list[str]]',
        'trs': 'str'
    }

    attribute_map = {
        'interval': 'interval',
        'trs': 'trs'
    }

    def __init__(self, interval=None, trs=None):  # noqa: E501
        """ExtentTemporal - a model defined in Swagger"""  # noqa: E501

        self._interval = None
        self._trs = None
        self.discriminator = None

        self.interval = interval
        if trs is not None:
            self.trs = trs

    @property
    def interval(self):
        """Gets the interval of this ExtentTemporal.  # noqa: E501

        One or more time intervals that describe the temporal extent of the dataset.  The first time interval describes the overall temporal extent of the data. All subsequent time intervals describe  more precise time intervals, e.g., to identify clusters of data. Clients only interested in the overall extent will only need to access the first item in each array.  # noqa: E501

        :return: The interval of this ExtentTemporal.  # noqa: E501
        :rtype: list[list[str]]
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this ExtentTemporal.

        One or more time intervals that describe the temporal extent of the dataset.  The first time interval describes the overall temporal extent of the data. All subsequent time intervals describe  more precise time intervals, e.g., to identify clusters of data. Clients only interested in the overall extent will only need to access the first item in each array.  # noqa: E501

        :param interval: The interval of this ExtentTemporal.  # noqa: E501
        :type: list[list[str]]
        """
        if interval is None:
            raise ValueError("Invalid value for `interval`, must not be `None`")  # noqa: E501

        self._interval = interval

    @property
    def trs(self):
        """Gets the trs of this ExtentTemporal.  # noqa: E501

        Coordinate reference system of the coordinates in the temporal extent (property `interval`). The default reference system is the Gregorian calendar. In the Core this is the only supported temporal reference system. Extensions may support additional temporal reference systems and add additional enum values.  # noqa: E501

        :return: The trs of this ExtentTemporal.  # noqa: E501
        :rtype: str
        """
        return self._trs

    @trs.setter
    def trs(self, trs):
        """Sets the trs of this ExtentTemporal.

        Coordinate reference system of the coordinates in the temporal extent (property `interval`). The default reference system is the Gregorian calendar. In the Core this is the only supported temporal reference system. Extensions may support additional temporal reference systems and add additional enum values.  # noqa: E501

        :param trs: The trs of this ExtentTemporal.  # noqa: E501
        :type: str
        """
        allowed_values = ["HTTP_WWW_OPENGIS_NET_DEF_UOM_ISO_8601_0_GREGORIAN"]  # noqa: E501
        if trs not in allowed_values:
            raise ValueError(
                "Invalid value for `trs` ({0}), must be one of {1}"  # noqa: E501
                .format(trs, allowed_values)
            )

        self._trs = trs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExtentTemporal, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExtentTemporal):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AggregationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'query_time': 'int',
        'total_time': 'int',
        'totalnb': 'int',
        'name': 'str',
        'count': 'int',
        'sumotherdoccounts': 'int',
        'key': 'object',
        'key_as_string': 'object',
        'elements': 'list[AggregationResponse]',
        'metrics': 'list[AggregationMetric]',
        'hits': 'list[object]',
        'geometries': 'list[ReturnedGeometry]',
        'flattened_elements': 'dict(str, object)'
    }

    attribute_map = {
        'query_time': 'query_time',
        'total_time': 'total_time',
        'totalnb': 'totalnb',
        'name': 'name',
        'count': 'count',
        'sumotherdoccounts': 'sumotherdoccounts',
        'key': 'key',
        'key_as_string': 'key_as_string',
        'elements': 'elements',
        'metrics': 'metrics',
        'hits': 'hits',
        'geometries': 'geometries',
        'flattened_elements': 'flattened_elements'
    }

    def __init__(self, query_time=None, total_time=None, totalnb=None, name=None, count=None, sumotherdoccounts=None, key=None, key_as_string=None, elements=None, metrics=None, hits=None, geometries=None, flattened_elements=None):  # noqa: E501
        """AggregationResponse - a model defined in Swagger"""  # noqa: E501

        self._query_time = None
        self._total_time = None
        self._totalnb = None
        self._name = None
        self._count = None
        self._sumotherdoccounts = None
        self._key = None
        self._key_as_string = None
        self._elements = None
        self._metrics = None
        self._hits = None
        self._geometries = None
        self._flattened_elements = None
        self.discriminator = None

        if query_time is not None:
            self.query_time = query_time
        if total_time is not None:
            self.total_time = total_time
        if totalnb is not None:
            self.totalnb = totalnb
        if name is not None:
            self.name = name
        if count is not None:
            self.count = count
        if sumotherdoccounts is not None:
            self.sumotherdoccounts = sumotherdoccounts
        if key is not None:
            self.key = key
        if key_as_string is not None:
            self.key_as_string = key_as_string
        if elements is not None:
            self.elements = elements
        if metrics is not None:
            self.metrics = metrics
        if hits is not None:
            self.hits = hits
        if geometries is not None:
            self.geometries = geometries
        if flattened_elements is not None:
            self.flattened_elements = flattened_elements

    @property
    def query_time(self):
        """Gets the query_time of this AggregationResponse.  # noqa: E501


        :return: The query_time of this AggregationResponse.  # noqa: E501
        :rtype: int
        """
        return self._query_time

    @query_time.setter
    def query_time(self, query_time):
        """Sets the query_time of this AggregationResponse.


        :param query_time: The query_time of this AggregationResponse.  # noqa: E501
        :type: int
        """

        self._query_time = query_time

    @property
    def total_time(self):
        """Gets the total_time of this AggregationResponse.  # noqa: E501


        :return: The total_time of this AggregationResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_time

    @total_time.setter
    def total_time(self, total_time):
        """Sets the total_time of this AggregationResponse.


        :param total_time: The total_time of this AggregationResponse.  # noqa: E501
        :type: int
        """

        self._total_time = total_time

    @property
    def totalnb(self):
        """Gets the totalnb of this AggregationResponse.  # noqa: E501


        :return: The totalnb of this AggregationResponse.  # noqa: E501
        :rtype: int
        """
        return self._totalnb

    @totalnb.setter
    def totalnb(self, totalnb):
        """Sets the totalnb of this AggregationResponse.


        :param totalnb: The totalnb of this AggregationResponse.  # noqa: E501
        :type: int
        """

        self._totalnb = totalnb

    @property
    def name(self):
        """Gets the name of this AggregationResponse.  # noqa: E501


        :return: The name of this AggregationResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AggregationResponse.


        :param name: The name of this AggregationResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def count(self):
        """Gets the count of this AggregationResponse.  # noqa: E501


        :return: The count of this AggregationResponse.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this AggregationResponse.


        :param count: The count of this AggregationResponse.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def sumotherdoccounts(self):
        """Gets the sumotherdoccounts of this AggregationResponse.  # noqa: E501


        :return: The sumotherdoccounts of this AggregationResponse.  # noqa: E501
        :rtype: int
        """
        return self._sumotherdoccounts

    @sumotherdoccounts.setter
    def sumotherdoccounts(self, sumotherdoccounts):
        """Sets the sumotherdoccounts of this AggregationResponse.


        :param sumotherdoccounts: The sumotherdoccounts of this AggregationResponse.  # noqa: E501
        :type: int
        """

        self._sumotherdoccounts = sumotherdoccounts

    @property
    def key(self):
        """Gets the key of this AggregationResponse.  # noqa: E501


        :return: The key of this AggregationResponse.  # noqa: E501
        :rtype: object
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this AggregationResponse.


        :param key: The key of this AggregationResponse.  # noqa: E501
        :type: object
        """

        self._key = key

    @property
    def key_as_string(self):
        """Gets the key_as_string of this AggregationResponse.  # noqa: E501


        :return: The key_as_string of this AggregationResponse.  # noqa: E501
        :rtype: object
        """
        return self._key_as_string

    @key_as_string.setter
    def key_as_string(self, key_as_string):
        """Sets the key_as_string of this AggregationResponse.


        :param key_as_string: The key_as_string of this AggregationResponse.  # noqa: E501
        :type: object
        """

        self._key_as_string = key_as_string

    @property
    def elements(self):
        """Gets the elements of this AggregationResponse.  # noqa: E501


        :return: The elements of this AggregationResponse.  # noqa: E501
        :rtype: list[AggregationResponse]
        """
        return self._elements

    @elements.setter
    def elements(self, elements):
        """Sets the elements of this AggregationResponse.


        :param elements: The elements of this AggregationResponse.  # noqa: E501
        :type: list[AggregationResponse]
        """

        self._elements = elements

    @property
    def metrics(self):
        """Gets the metrics of this AggregationResponse.  # noqa: E501


        :return: The metrics of this AggregationResponse.  # noqa: E501
        :rtype: list[AggregationMetric]
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """Sets the metrics of this AggregationResponse.


        :param metrics: The metrics of this AggregationResponse.  # noqa: E501
        :type: list[AggregationMetric]
        """

        self._metrics = metrics

    @property
    def hits(self):
        """Gets the hits of this AggregationResponse.  # noqa: E501


        :return: The hits of this AggregationResponse.  # noqa: E501
        :rtype: list[object]
        """
        return self._hits

    @hits.setter
    def hits(self, hits):
        """Sets the hits of this AggregationResponse.


        :param hits: The hits of this AggregationResponse.  # noqa: E501
        :type: list[object]
        """

        self._hits = hits

    @property
    def geometries(self):
        """Gets the geometries of this AggregationResponse.  # noqa: E501


        :return: The geometries of this AggregationResponse.  # noqa: E501
        :rtype: list[ReturnedGeometry]
        """
        return self._geometries

    @geometries.setter
    def geometries(self, geometries):
        """Sets the geometries of this AggregationResponse.


        :param geometries: The geometries of this AggregationResponse.  # noqa: E501
        :type: list[ReturnedGeometry]
        """

        self._geometries = geometries

    @property
    def flattened_elements(self):
        """Gets the flattened_elements of this AggregationResponse.  # noqa: E501


        :return: The flattened_elements of this AggregationResponse.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._flattened_elements

    @flattened_elements.setter
    def flattened_elements(self, flattened_elements):
        """Sets the flattened_elements of this AggregationResponse.


        :param flattened_elements: The flattened_elements of this AggregationResponse.  # noqa: E501
        :type: dict(str, object)
        """

        self._flattened_elements = flattened_elements

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AggregationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AggregationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Hits(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'collection': 'str',
        'hits': 'list[Hit]',
        'nbhits': 'int',
        'totalnb': 'int',
        'links': 'dict(str, Link)'
    }

    attribute_map = {
        'collection': 'collection',
        'hits': 'hits',
        'nbhits': 'nbhits',
        'totalnb': 'totalnb',
        'links': 'links'
    }

    def __init__(self, collection=None, hits=None, nbhits=None, totalnb=None, links=None):  # noqa: E501
        """Hits - a model defined in Swagger"""  # noqa: E501

        self._collection = None
        self._hits = None
        self._nbhits = None
        self._totalnb = None
        self._links = None
        self.discriminator = None

        if collection is not None:
            self.collection = collection
        if hits is not None:
            self.hits = hits
        if nbhits is not None:
            self.nbhits = nbhits
        if totalnb is not None:
            self.totalnb = totalnb
        if links is not None:
            self.links = links

    @property
    def collection(self):
        """Gets the collection of this Hits.  # noqa: E501


        :return: The collection of this Hits.  # noqa: E501
        :rtype: str
        """
        return self._collection

    @collection.setter
    def collection(self, collection):
        """Sets the collection of this Hits.


        :param collection: The collection of this Hits.  # noqa: E501
        :type: str
        """

        self._collection = collection

    @property
    def hits(self):
        """Gets the hits of this Hits.  # noqa: E501


        :return: The hits of this Hits.  # noqa: E501
        :rtype: list[Hit]
        """
        return self._hits

    @hits.setter
    def hits(self, hits):
        """Sets the hits of this Hits.


        :param hits: The hits of this Hits.  # noqa: E501
        :type: list[Hit]
        """

        self._hits = hits

    @property
    def nbhits(self):
        """Gets the nbhits of this Hits.  # noqa: E501


        :return: The nbhits of this Hits.  # noqa: E501
        :rtype: int
        """
        return self._nbhits

    @nbhits.setter
    def nbhits(self, nbhits):
        """Sets the nbhits of this Hits.


        :param nbhits: The nbhits of this Hits.  # noqa: E501
        :type: int
        """

        self._nbhits = nbhits

    @property
    def totalnb(self):
        """Gets the totalnb of this Hits.  # noqa: E501


        :return: The totalnb of this Hits.  # noqa: E501
        :rtype: int
        """
        return self._totalnb

    @totalnb.setter
    def totalnb(self, totalnb):
        """Sets the totalnb of this Hits.


        :param totalnb: The totalnb of this Hits.  # noqa: E501
        :type: int
        """

        self._totalnb = totalnb

    @property
    def links(self):
        """Gets the links of this Hits.  # noqa: E501


        :return: The links of this Hits.  # noqa: E501
        :rtype: dict(str, Link)
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this Hits.


        :param links: The links of this Hits.  # noqa: E501
        :type: dict(str, Link)
        """

        self._links = links

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Hits, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Hits):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StacFeatureCollection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'stac_version': 'str',
        'stac_extensions': 'list[str]',
        'type': 'str',
        'features': 'list[Item]',
        'links': 'list[StacLink]',
        'time_stamp': 'str',
        'number_matched': 'int',
        'number_returned': 'int',
        'context': 'dict(str, object)'
    }

    attribute_map = {
        'stac_version': 'stac_version',
        'stac_extensions': 'stac_extensions',
        'type': 'type',
        'features': 'features',
        'links': 'links',
        'time_stamp': 'timeStamp',
        'number_matched': 'numberMatched',
        'number_returned': 'numberReturned',
        'context': 'context'
    }

    def __init__(self, stac_version=None, stac_extensions=None, type=None, features=None, links=None, time_stamp=None, number_matched=None, number_returned=None, context=None):  # noqa: E501
        """StacFeatureCollection - a model defined in Swagger"""  # noqa: E501

        self._stac_version = None
        self._stac_extensions = None
        self._type = None
        self._features = None
        self._links = None
        self._time_stamp = None
        self._number_matched = None
        self._number_returned = None
        self._context = None
        self.discriminator = None

        self.stac_version = stac_version
        if stac_extensions is not None:
            self.stac_extensions = stac_extensions
        self.type = type
        self.features = features
        if links is not None:
            self.links = links
        if time_stamp is not None:
            self.time_stamp = time_stamp
        if number_matched is not None:
            self.number_matched = number_matched
        if number_returned is not None:
            self.number_returned = number_returned
        if context is not None:
            self.context = context

    @property
    def stac_version(self):
        """Gets the stac_version of this StacFeatureCollection.  # noqa: E501


        :return: The stac_version of this StacFeatureCollection.  # noqa: E501
        :rtype: str
        """
        return self._stac_version

    @stac_version.setter
    def stac_version(self, stac_version):
        """Sets the stac_version of this StacFeatureCollection.


        :param stac_version: The stac_version of this StacFeatureCollection.  # noqa: E501
        :type: str
        """
        if stac_version is None:
            raise ValueError("Invalid value for `stac_version`, must not be `None`")  # noqa: E501

        self._stac_version = stac_version

    @property
    def stac_extensions(self):
        """Gets the stac_extensions of this StacFeatureCollection.  # noqa: E501


        :return: The stac_extensions of this StacFeatureCollection.  # noqa: E501
        :rtype: list[str]
        """
        return self._stac_extensions

    @stac_extensions.setter
    def stac_extensions(self, stac_extensions):
        """Sets the stac_extensions of this StacFeatureCollection.


        :param stac_extensions: The stac_extensions of this StacFeatureCollection.  # noqa: E501
        :type: list[str]
        """

        self._stac_extensions = stac_extensions

    @property
    def type(self):
        """Gets the type of this StacFeatureCollection.  # noqa: E501


        :return: The type of this StacFeatureCollection.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this StacFeatureCollection.


        :param type: The type of this StacFeatureCollection.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def features(self):
        """Gets the features of this StacFeatureCollection.  # noqa: E501


        :return: The features of this StacFeatureCollection.  # noqa: E501
        :rtype: list[Item]
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this StacFeatureCollection.


        :param features: The features of this StacFeatureCollection.  # noqa: E501
        :type: list[Item]
        """
        if features is None:
            raise ValueError("Invalid value for `features`, must not be `None`")  # noqa: E501

        self._features = features

    @property
    def links(self):
        """Gets the links of this StacFeatureCollection.  # noqa: E501


        :return: The links of this StacFeatureCollection.  # noqa: E501
        :rtype: list[StacLink]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this StacFeatureCollection.


        :param links: The links of this StacFeatureCollection.  # noqa: E501
        :type: list[StacLink]
        """

        self._links = links

    @property
    def time_stamp(self):
        """Gets the time_stamp of this StacFeatureCollection.  # noqa: E501


        :return: The time_stamp of this StacFeatureCollection.  # noqa: E501
        :rtype: str
        """
        return self._time_stamp

    @time_stamp.setter
    def time_stamp(self, time_stamp):
        """Sets the time_stamp of this StacFeatureCollection.


        :param time_stamp: The time_stamp of this StacFeatureCollection.  # noqa: E501
        :type: str
        """

        self._time_stamp = time_stamp

    @property
    def number_matched(self):
        """Gets the number_matched of this StacFeatureCollection.  # noqa: E501


        :return: The number_matched of this StacFeatureCollection.  # noqa: E501
        :rtype: int
        """
        return self._number_matched

    @number_matched.setter
    def number_matched(self, number_matched):
        """Sets the number_matched of this StacFeatureCollection.


        :param number_matched: The number_matched of this StacFeatureCollection.  # noqa: E501
        :type: int
        """

        self._number_matched = number_matched

    @property
    def number_returned(self):
        """Gets the number_returned of this StacFeatureCollection.  # noqa: E501


        :return: The number_returned of this StacFeatureCollection.  # noqa: E501
        :rtype: int
        """
        return self._number_returned

    @number_returned.setter
    def number_returned(self, number_returned):
        """Sets the number_returned of this StacFeatureCollection.


        :param number_returned: The number_returned of this StacFeatureCollection.  # noqa: E501
        :type: int
        """

        self._number_returned = number_returned

    @property
    def context(self):
        """Gets the context of this StacFeatureCollection.  # noqa: E501

        Augments lists of resources with the number of returned and matches resource and the given limit for the request.  # noqa: E501

        :return: The context of this StacFeatureCollection.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this StacFeatureCollection.

        Augments lists of resources with the number of returned and matches resource and the given limit for the request.  # noqa: E501

        :param context: The context of this StacFeatureCollection.  # noqa: E501
        :type: dict(str, object)
        """

        self._context = context

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StacFeatureCollection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StacFeatureCollection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Provider(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'roles': 'list[str]',
        'url': 'str'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'roles': 'roles',
        'url': 'url'
    }

    def __init__(self, name=None, description=None, roles=None, url=None):  # noqa: E501
        """Provider - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._description = None
        self._roles = None
        self._url = None
        self.discriminator = None

        self.name = name
        if description is not None:
            self.description = description
        if roles is not None:
            self.roles = roles
        if url is not None:
            self.url = url

    @property
    def name(self):
        """Gets the name of this Provider.  # noqa: E501

        The name of the organization or the individual.  # noqa: E501

        :return: The name of this Provider.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Provider.

        The name of the organization or the individual.  # noqa: E501

        :param name: The name of this Provider.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this Provider.  # noqa: E501

        Multi-line description to add further provider information such as processing details for processors and producers, hosting details for hosts or basic contact information.  [CommonMark 0.29](http://commonmark.org/) syntax MAY be used for rich text representation.  # noqa: E501

        :return: The description of this Provider.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Provider.

        Multi-line description to add further provider information such as processing details for processors and producers, hosting details for hosts or basic contact information.  [CommonMark 0.29](http://commonmark.org/) syntax MAY be used for rich text representation.  # noqa: E501

        :param description: The description of this Provider.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def roles(self):
        """Gets the roles of this Provider.  # noqa: E501

        Roles of the provider.  The provider's role(s) can be one or more of the following elements:  * licensor: The organization that is licensing the dataset under   the license specified in the collection's license field. * producer: The producer of the data is the provider that   initially captured and processed the source data, e.g. ESA for   Sentinel-2 data. * processor: A processor is any provider who processed data to a   derived product. * host: The host is the actual provider offering the data on their   storage. There should be no more than one host, specified as last   element of the list.  # noqa: E501

        :return: The roles of this Provider.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this Provider.

        Roles of the provider.  The provider's role(s) can be one or more of the following elements:  * licensor: The organization that is licensing the dataset under   the license specified in the collection's license field. * producer: The producer of the data is the provider that   initially captured and processed the source data, e.g. ESA for   Sentinel-2 data. * processor: A processor is any provider who processed data to a   derived product. * host: The host is the actual provider offering the data on their   storage. There should be no more than one host, specified as last   element of the list.  # noqa: E501

        :param roles: The roles of this Provider.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["PRODUCER", "LICENSOR", "PROCESSOR", "HOST"]  # noqa: E501
        if not set(roles).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `roles` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(roles) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._roles = roles

    @property
    def url(self):
        """Gets the url of this Provider.  # noqa: E501

        Homepage on which the provider describes the dataset and publishes contact information.  # noqa: E501

        :return: The url of this Provider.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Provider.

        Homepage on which the provider describes the dataset and publishes contact information.  # noqa: E501

        :param url: The url of this Provider.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Provider, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Provider):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from arlas_api_python.api.collections_api import CollectionsApi
from arlas_api_python.api.explore_api import ExploreApi
from arlas_api_python.api.stac_api import StacApi

# import ApiClient
from arlas_api_python.api_client import ApiClient
from arlas_api_python.configuration import Configuration
# import models into sdk package
from arlas_api_python.models.aggregation import Aggregation
from arlas_api_python.models.aggregation_metric import AggregationMetric
from arlas_api_python.models.aggregation_response import AggregationResponse
from arlas_api_python.models.aggregations_request import AggregationsRequest
from arlas_api_python.models.bbox import Bbox
from arlas_api_python.models.collection import Collection
from arlas_api_python.models.collection_list import CollectionList
from arlas_api_python.models.collection_reference import CollectionReference
from arlas_api_python.models.collection_reference_description import CollectionReferenceDescription
from arlas_api_python.models.collection_reference_description_property import CollectionReferenceDescriptionProperty
from arlas_api_python.models.collection_reference_parameters import CollectionReferenceParameters
from arlas_api_python.models.computation_request import ComputationRequest
from arlas_api_python.models.computation_response import ComputationResponse
from arlas_api_python.models.conformance_classes import ConformanceClasses
from arlas_api_python.models.count import Count
from arlas_api_python.models.crs import Crs
from arlas_api_python.models.dublin_core_element_name import DublinCoreElementName
from arlas_api_python.models.error import Error
from arlas_api_python.models.expression import Expression
from arlas_api_python.models.extent import Extent
from arlas_api_python.models.extent_spatial import ExtentSpatial
from arlas_api_python.models.extent_temporal import ExtentTemporal
from arlas_api_python.models.feed import Feed
from arlas_api_python.models.filter import Filter
from arlas_api_python.models.form import Form
from arlas_api_python.models.generator import Generator
from arlas_api_python.models.geo import Geo
from arlas_api_python.models.geo_json_object import GeoJsonObject
from arlas_api_python.models.hit import Hit
from arlas_api_python.models.hits import Hits
from arlas_api_python.models.hits_fetcher import HitsFetcher
from arlas_api_python.models.inspire import Inspire
from arlas_api_python.models.inspire_limitation_access import InspireLimitationAccess
from arlas_api_python.models.inspire_spatial_resolution import InspireSpatialResolution
from arlas_api_python.models.inspire_uri import InspireURI
from arlas_api_python.models.interval import Interval
from arlas_api_python.models.item import Item
from arlas_api_python.models.keyword import Keyword
from arlas_api_python.models.landing_page import LandingPage
from arlas_api_python.models.link import Link
from arlas_api_python.models.lng_lat_alt import LngLatAlt
from arlas_api_python.models.md import MD
from arlas_api_python.models.metric import Metric
from arlas_api_python.models.number import Number
from arlas_api_python.models.open_search import OpenSearch
from arlas_api_python.models.page import Page
from arlas_api_python.models.person import Person
from arlas_api_python.models.projection import Projection
from arlas_api_python.models.provider import Provider
from arlas_api_python.models.raster_tile_url import RasterTileURL
from arlas_api_python.models.raw_geometry import RawGeometry
from arlas_api_python.models.returned_geometry import ReturnedGeometry
from arlas_api_python.models.search import Search
from arlas_api_python.models.search_body import SearchBody
from arlas_api_python.models.stac_feature_collection import StacFeatureCollection
from arlas_api_python.models.stac_link import StacLink
from arlas_api_python.models.success import Success
from arlas_api_python.models.feature import Feature
from arlas_api_python.models.feature_collection import FeatureCollection
from arlas_api_python.models.geometry_collection import GeometryCollection
from arlas_api_python.models.line_string import LineString
from arlas_api_python.models.multi_line_string import MultiLineString
from arlas_api_python.models.multi_point import MultiPoint
from arlas_api_python.models.multi_polygon import MultiPolygon
from arlas_api_python.models.point import Point
from arlas_api_python.models.polygon import Polygon



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SearchBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bbox': 'list[float]',
        '_datetime': 'str',
        'intersects': 'object',
        'collections': 'list[str]',
        'ids': 'list[str]',
        'limit': 'int',
        '_from': 'int',
        'sortby': 'str',
        'after': 'str',
        'before': 'str'
    }

    attribute_map = {
        'bbox': 'bbox',
        '_datetime': 'datetime',
        'intersects': 'intersects',
        'collections': 'collections',
        'ids': 'ids',
        'limit': 'limit',
        '_from': 'from',
        'sortby': 'sortby',
        'after': 'after',
        'before': 'before'
    }

    def __init__(self, bbox=None, _datetime=None, intersects=None, collections=None, ids=None, limit=None, _from=None, sortby=None, after=None, before=None):  # noqa: E501
        """SearchBody - a model defined in Swagger"""  # noqa: E501

        self._bbox = None
        self.__datetime = None
        self._intersects = None
        self._collections = None
        self._ids = None
        self._limit = None
        self.__from = None
        self._sortby = None
        self._after = None
        self._before = None
        self.discriminator = None

        if bbox is not None:
            self.bbox = bbox
        if _datetime is not None:
            self._datetime = _datetime
        if intersects is not None:
            self.intersects = intersects
        if collections is not None:
            self.collections = collections
        if ids is not None:
            self.ids = ids
        if limit is not None:
            self.limit = limit
        if _from is not None:
            self._from = _from
        if sortby is not None:
            self.sortby = sortby
        if after is not None:
            self.after = after
        if before is not None:
            self.before = before

    @property
    def bbox(self):
        """Gets the bbox of this SearchBody.  # noqa: E501


        :return: The bbox of this SearchBody.  # noqa: E501
        :rtype: list[float]
        """
        return self._bbox

    @bbox.setter
    def bbox(self, bbox):
        """Sets the bbox of this SearchBody.


        :param bbox: The bbox of this SearchBody.  # noqa: E501
        :type: list[float]
        """

        self._bbox = bbox

    @property
    def _datetime(self):
        """Gets the _datetime of this SearchBody.  # noqa: E501


        :return: The _datetime of this SearchBody.  # noqa: E501
        :rtype: str
        """
        return self.__datetime

    @_datetime.setter
    def _datetime(self, _datetime):
        """Sets the _datetime of this SearchBody.


        :param _datetime: The _datetime of this SearchBody.  # noqa: E501
        :type: str
        """

        self.__datetime = _datetime

    @property
    def intersects(self):
        """Gets the intersects of this SearchBody.  # noqa: E501


        :return: The intersects of this SearchBody.  # noqa: E501
        :rtype: object
        """
        return self._intersects

    @intersects.setter
    def intersects(self, intersects):
        """Sets the intersects of this SearchBody.


        :param intersects: The intersects of this SearchBody.  # noqa: E501
        :type: object
        """

        self._intersects = intersects

    @property
    def collections(self):
        """Gets the collections of this SearchBody.  # noqa: E501


        :return: The collections of this SearchBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._collections

    @collections.setter
    def collections(self, collections):
        """Sets the collections of this SearchBody.


        :param collections: The collections of this SearchBody.  # noqa: E501
        :type: list[str]
        """

        self._collections = collections

    @property
    def ids(self):
        """Gets the ids of this SearchBody.  # noqa: E501


        :return: The ids of this SearchBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._ids

    @ids.setter
    def ids(self, ids):
        """Sets the ids of this SearchBody.


        :param ids: The ids of this SearchBody.  # noqa: E501
        :type: list[str]
        """

        self._ids = ids

    @property
    def limit(self):
        """Gets the limit of this SearchBody.  # noqa: E501


        :return: The limit of this SearchBody.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this SearchBody.


        :param limit: The limit of this SearchBody.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def _from(self):
        """Gets the _from of this SearchBody.  # noqa: E501


        :return: The _from of this SearchBody.  # noqa: E501
        :rtype: int
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this SearchBody.


        :param _from: The _from of this SearchBody.  # noqa: E501
        :type: int
        """

        self.__from = _from

    @property
    def sortby(self):
        """Gets the sortby of this SearchBody.  # noqa: E501


        :return: The sortby of this SearchBody.  # noqa: E501
        :rtype: str
        """
        return self._sortby

    @sortby.setter
    def sortby(self, sortby):
        """Sets the sortby of this SearchBody.


        :param sortby: The sortby of this SearchBody.  # noqa: E501
        :type: str
        """

        self._sortby = sortby

    @property
    def after(self):
        """Gets the after of this SearchBody.  # noqa: E501


        :return: The after of this SearchBody.  # noqa: E501
        :rtype: str
        """
        return self._after

    @after.setter
    def after(self, after):
        """Sets the after of this SearchBody.


        :param after: The after of this SearchBody.  # noqa: E501
        :type: str
        """

        self._after = after

    @property
    def before(self):
        """Gets the before of this SearchBody.  # noqa: E501


        :return: The before of this SearchBody.  # noqa: E501
        :rtype: str
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this SearchBody.


        :param before: The before of this SearchBody.  # noqa: E501
        :type: str
        """

        self._before = before

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SearchBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Collection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'stac_version': 'str',
        'stac_extensions': 'list[str]',
        'type': 'str',
        'id': 'str',
        'title': 'str',
        'description': 'str',
        'links': 'list[StacLink]',
        'keywords': 'list[str]',
        'crs': 'list[str]',
        'license': 'str',
        'extent': 'Extent',
        'providers': 'list[Provider]',
        'summaries': 'dict(str, object)',
        'assets': 'dict(str, object)'
    }

    attribute_map = {
        'stac_version': 'stac_version',
        'stac_extensions': 'stac_extensions',
        'type': 'type',
        'id': 'id',
        'title': 'title',
        'description': 'description',
        'links': 'links',
        'keywords': 'keywords',
        'crs': 'crs',
        'license': 'license',
        'extent': 'extent',
        'providers': 'providers',
        'summaries': 'summaries',
        'assets': 'assets'
    }

    def __init__(self, stac_version=None, stac_extensions=None, type=None, id=None, title=None, description=None, links=None, keywords=None, crs=None, license=None, extent=None, providers=None, summaries=None, assets=None):  # noqa: E501
        """Collection - a model defined in Swagger"""  # noqa: E501

        self._stac_version = None
        self._stac_extensions = None
        self._type = None
        self._id = None
        self._title = None
        self._description = None
        self._links = None
        self._keywords = None
        self._crs = None
        self._license = None
        self._extent = None
        self._providers = None
        self._summaries = None
        self._assets = None
        self.discriminator = None

        self.stac_version = stac_version
        if stac_extensions is not None:
            self.stac_extensions = stac_extensions
        self.type = type
        self.id = id
        if title is not None:
            self.title = title
        self.description = description
        self.links = links
        if keywords is not None:
            self.keywords = keywords
        if crs is not None:
            self.crs = crs
        self.license = license
        self.extent = extent
        if providers is not None:
            self.providers = providers
        if summaries is not None:
            self.summaries = summaries
        if assets is not None:
            self.assets = assets

    @property
    def stac_version(self):
        """Gets the stac_version of this Collection.  # noqa: E501


        :return: The stac_version of this Collection.  # noqa: E501
        :rtype: str
        """
        return self._stac_version

    @stac_version.setter
    def stac_version(self, stac_version):
        """Sets the stac_version of this Collection.


        :param stac_version: The stac_version of this Collection.  # noqa: E501
        :type: str
        """
        if stac_version is None:
            raise ValueError("Invalid value for `stac_version`, must not be `None`")  # noqa: E501

        self._stac_version = stac_version

    @property
    def stac_extensions(self):
        """Gets the stac_extensions of this Collection.  # noqa: E501


        :return: The stac_extensions of this Collection.  # noqa: E501
        :rtype: list[str]
        """
        return self._stac_extensions

    @stac_extensions.setter
    def stac_extensions(self, stac_extensions):
        """Sets the stac_extensions of this Collection.


        :param stac_extensions: The stac_extensions of this Collection.  # noqa: E501
        :type: list[str]
        """

        self._stac_extensions = stac_extensions

    @property
    def type(self):
        """Gets the type of this Collection.  # noqa: E501


        :return: The type of this Collection.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Collection.


        :param type: The type of this Collection.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def id(self):
        """Gets the id of this Collection.  # noqa: E501

        identifier of the collection used, for example, in URIs  # noqa: E501

        :return: The id of this Collection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Collection.

        identifier of the collection used, for example, in URIs  # noqa: E501

        :param id: The id of this Collection.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def title(self):
        """Gets the title of this Collection.  # noqa: E501

        human readable title of the collection  # noqa: E501

        :return: The title of this Collection.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Collection.

        human readable title of the collection  # noqa: E501

        :param title: The title of this Collection.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def description(self):
        """Gets the description of this Collection.  # noqa: E501

        Detailed multi-line description to fully explain the catalog or collection. [CommonMark 0.29](http://commonmark.org/) syntax MAY be used for rich text representation.  # noqa: E501

        :return: The description of this Collection.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Collection.

        Detailed multi-line description to fully explain the catalog or collection. [CommonMark 0.29](http://commonmark.org/) syntax MAY be used for rich text representation.  # noqa: E501

        :param description: The description of this Collection.  # noqa: E501
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def links(self):
        """Gets the links of this Collection.  # noqa: E501


        :return: The links of this Collection.  # noqa: E501
        :rtype: list[StacLink]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this Collection.


        :param links: The links of this Collection.  # noqa: E501
        :type: list[StacLink]
        """
        if links is None:
            raise ValueError("Invalid value for `links`, must not be `None`")  # noqa: E501

        self._links = links

    @property
    def keywords(self):
        """Gets the keywords of this Collection.  # noqa: E501

        List of keywords describing the collection.  # noqa: E501

        :return: The keywords of this Collection.  # noqa: E501
        :rtype: list[str]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this Collection.

        List of keywords describing the collection.  # noqa: E501

        :param keywords: The keywords of this Collection.  # noqa: E501
        :type: list[str]
        """

        self._keywords = keywords

    @property
    def crs(self):
        """Gets the crs of this Collection.  # noqa: E501

        List of crs describing the collection.  # noqa: E501

        :return: The crs of this Collection.  # noqa: E501
        :rtype: list[str]
        """
        return self._crs

    @crs.setter
    def crs(self, crs):
        """Sets the crs of this Collection.

        List of crs describing the collection.  # noqa: E501

        :param crs: The crs of this Collection.  # noqa: E501
        :type: list[str]
        """

        self._crs = crs

    @property
    def license(self):
        """Gets the license of this Collection.  # noqa: E501


        :return: The license of this Collection.  # noqa: E501
        :rtype: str
        """
        return self._license

    @license.setter
    def license(self, license):
        """Sets the license of this Collection.


        :param license: The license of this Collection.  # noqa: E501
        :type: str
        """
        if license is None:
            raise ValueError("Invalid value for `license`, must not be `None`")  # noqa: E501

        self._license = license

    @property
    def extent(self):
        """Gets the extent of this Collection.  # noqa: E501


        :return: The extent of this Collection.  # noqa: E501
        :rtype: Extent
        """
        return self._extent

    @extent.setter
    def extent(self, extent):
        """Sets the extent of this Collection.


        :param extent: The extent of this Collection.  # noqa: E501
        :type: Extent
        """
        if extent is None:
            raise ValueError("Invalid value for `extent`, must not be `None`")  # noqa: E501

        self._extent = extent

    @property
    def providers(self):
        """Gets the providers of this Collection.  # noqa: E501


        :return: The providers of this Collection.  # noqa: E501
        :rtype: list[Provider]
        """
        return self._providers

    @providers.setter
    def providers(self, providers):
        """Sets the providers of this Collection.


        :param providers: The providers of this Collection.  # noqa: E501
        :type: list[Provider]
        """

        self._providers = providers

    @property
    def summaries(self):
        """Gets the summaries of this Collection.  # noqa: E501

        Summaries are either a unique set of all available values *or* statistics. Statistics by default only specify the range (minimum and maximum values), but can optionally be accompanied by additional statistical values. The range can specify the potential range of values, but it is recommended to be as precise as possible. The set of values must contain at least one element and it is strongly recommended to list all values. It is recommended to list as many properties as reasonable so that consumers get a full overview of the Collection. Properties that are covered by the Collection specification (e.g. `providers` and `license`) may not be repeated in the summaries.  # noqa: E501

        :return: The summaries of this Collection.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._summaries

    @summaries.setter
    def summaries(self, summaries):
        """Sets the summaries of this Collection.

        Summaries are either a unique set of all available values *or* statistics. Statistics by default only specify the range (minimum and maximum values), but can optionally be accompanied by additional statistical values. The range can specify the potential range of values, but it is recommended to be as precise as possible. The set of values must contain at least one element and it is strongly recommended to list all values. It is recommended to list as many properties as reasonable so that consumers get a full overview of the Collection. Properties that are covered by the Collection specification (e.g. `providers` and `license`) may not be repeated in the summaries.  # noqa: E501

        :param summaries: The summaries of this Collection.  # noqa: E501
        :type: dict(str, object)
        """

        self._summaries = summaries

    @property
    def assets(self):
        """Gets the assets of this Collection.  # noqa: E501

        This provides an optional mechanism to expose assets that don't make sense at the Item level.  # noqa: E501

        :return: The assets of this Collection.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._assets

    @assets.setter
    def assets(self, assets):
        """Sets the assets of this Collection.

        This provides an optional mechanism to expose assets that don't make sense at the Item level.  # noqa: E501

        :param assets: The assets of this Collection.  # noqa: E501
        :type: dict(str, object)
        """

        self._assets = assets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Collection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Collection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
